@@ -68,7 +68,10 @@ class TCP;
 
 \author Jasem Mutlaq
 */
-class INDI::Dome : public INDI::DefaultDevice
+namespace INDI
+{
+
+class Dome : public DefaultDevice
 {
   public:
     /** \typedef DomeMeasurements
@@ -170,7 +173,7 @@ class INDI::Dome : public INDI::DefaultDevice
     static void buttonHelper(const char *button_n, ISState state, void *context);
 
     /**
-         * @brief setDomeConnection Set Dome connection mode. Child class should call this in the constructor before INDI::Dome registers
+         * @brief setDomeConnection Set Dome connection mode. Child class should call this in the constructor before Dome registers
          * any connection interfaces
          * @param value ORed combination of DomeConnection values.
          */
@@ -505,33 +508,42 @@ class INDI::Dome : public INDI::DefaultDevice
     Connection::Serial *serialConnection = NULL;
     Connection::TCP *tcpConnection       = NULL;
 
+    // States
+    DomeState domeState;
+    IPState mountState;
+    IPState weatherState;
+
+    // Observer geographic coords. Snooped from mount driver.
+    struct ln_lnlat_posn observer;
+    // Do we have valid geographic coords from mount driver?
+    bool HaveLatLong = false;
+
+
+    // Mount horizontal and equatorial coords. Snoops from mount driver.
+    struct ln_hrz_posn mountHoriztonalCoords;
+    struct ln_equ_posn mountEquatorialCoords;
+    // Do we have valid coords from mount driver?
+    bool HaveRaDec = false;
+
   private:
     void processButton(const char *button_n, ISState state);
 
     void triggerSnoop(const char *driverName, const char *propertyName);
 
-    INDI::Controller *controller;
+    Controller *controller = nullptr;
 
-    DomeState domeState;
+    bool IsParked = false;
+    bool IsLocked = true;
 
-    struct ln_lnlat_posn observer;
-    struct ln_hrz_posn mountHoriztonalCoords;
-    struct ln_equ_posn mountEquatorialCoords;
-
-    IPState mountState;
-    IPState weatherState;
-
-    bool IsParked;
-    bool IsLocked;
     const char *ParkDeviceName;
     const char *Parkdatafile;
     XMLEle *ParkdataXmlRoot, *ParkdeviceXml, *ParkstatusXml, *ParkpositionXml, *ParkpositionAxis1Xml;
 
     double Axis1ParkPosition;
     double Axis1DefaultParkPosition;
-    bool HaveLatLong;
-    bool HaveRaDec;
 
     bool callHandshake();
     uint8_t domeConnection = CONNECTION_SERIAL | CONNECTION_TCP;
 };
+
+}
